@@ -28,16 +28,19 @@ const OUT_RESULT_ARG_NAME: &str = "out-result";
 const GET_LOCATIONS_ARG_NAME: &str = "get-locations";
 const CONFIG_ARG_NAME: &str = "config";
 
+#[allow(clippy::type_complexity)]
 struct ProblemReader(pub Box<dyn Fn(File, Option<Vec<File>>) -> Result<Problem, String>>);
 
 struct InitSolutionReader(pub Box<dyn Fn(File, Arc<Problem>) -> Option<Solution>>);
 
+#[allow(clippy::type_complexity)]
 struct SolutionWriter(
     pub  Box<
         dyn Fn(&Problem, Solution, BufWriter<Box<dyn Write>>, Option<BufWriter<Box<dyn Write>>>) -> Result<(), String>,
     >,
 );
 
+#[allow(clippy::type_complexity)]
 struct LocationWriter(pub Box<dyn Fn(File, BufWriter<Box<dyn Write>>) -> Result<(), String>>);
 
 fn get_formats<'a>() -> HashMap<&'a str, (ProblemReader, InitSolutionReader, SolutionWriter, LocationWriter)> {
@@ -71,7 +74,7 @@ fn get_formats<'a>() -> HashMap<&'a str, (ProblemReader, InitSolutionReader, Sol
             (
                 ProblemReader(Box::new(|problem: File, matrices: Option<Vec<File>>| {
                     if let Some(matrices) = matrices {
-                        let matrices = matrices.into_iter().map(|m| BufReader::new(m)).collect();
+                        let matrices = matrices.into_iter().map(BufReader::new).collect();
                         (BufReader::new(problem), matrices).read_pragmatic()
                     } else {
                         println!("configured to use single approximated routing matrix");
