@@ -24,14 +24,14 @@ pub enum MutationConfig {
     #[serde(rename(deserialize = "ruin-recreate"))]
     RuinRecreate {
         /// Ruin methods.
-        ruins: Vec<RuinMethodGroup>,
+        ruins: Vec<ConfigRuinGroup>,
         /// Recreate methods.
         recreates: Vec<RecreateMethod>,
     },
 }
 
 #[derive(Clone, Deserialize, Debug)]
-pub struct RuinMethodGroup {
+pub struct ConfigRuinGroup {
     methods: Vec<RuinMethod>,
     weight: usize,
 }
@@ -71,6 +71,7 @@ pub enum RecreateMethod {
 }
 
 #[derive(Clone, Deserialize, Debug)]
+#[serde(rename_all = "camelCase")]
 pub struct PopulationConfig {
     initial_methods: Option<Vec<RecreateMethod>>,
     initial_size: Option<usize>,
@@ -80,6 +81,7 @@ pub struct PopulationConfig {
 }
 
 #[derive(Clone, Deserialize, Debug)]
+#[serde(rename_all = "camelCase")]
 pub struct TerminationConfig {
     max_time: Option<usize>,
     max_generations: Option<usize>,
@@ -152,7 +154,7 @@ fn create_recreate_method(method: &RecreateMethod) -> (Box<dyn Recreate>, usize)
     }
 }
 
-fn create_ruin_group(problem: &Arc<Problem>, group: &RuinMethodGroup) -> (Vec<(Arc<dyn Ruin>, f64)>, usize) {
+fn create_ruin_group(problem: &Arc<Problem>, group: &ConfigRuinGroup) -> RuinGroup {
     (group.methods.iter().map(|r| create_ruin_method(problem, r)).collect(), group.weight)
 }
 
