@@ -1,4 +1,14 @@
-//! A VRP library public API.
+//! A crate for solving Vehicle Routing Problem using default metaheuristic.
+//!
+//!
+//! This crate provides ready-to-use functionality to solve rich ***Vehicle Routing Problem***.
+//!
+//! For more details check the following resources:
+//!
+//! - [`user guide`](https://reinterpretcat.github.io/vrp) describes how to use cli
+//!   application built from this crate
+//! - [`core crate`](../vrp_core/index.html) implements default metaheuristic
+//!
 
 #[cfg(not(target_arch = "wasm32"))]
 #[cfg(test)]
@@ -188,7 +198,7 @@ pub fn get_locations_serialized(problem: &Problem) -> Result<String, String> {
     Ok(buffer)
 }
 
-pub fn get_solution_serialized(problem: &Arc<CoreProblem>, config_str: &String) -> Result<String, String> {
+pub fn get_solution_serialized(problem: &Arc<CoreProblem>, config_str: &str) -> Result<String, String> {
     let config = read_config(BufReader::new(config_str.as_bytes())).map_err(|err| {
         FormatError::new(
             "E0004".to_string(),
@@ -217,6 +227,6 @@ pub fn get_solution_serialized(problem: &Arc<CoreProblem>, config_str: &String)
     Ok(buffer)
 }
 
-pub fn get_errors_serialized(errors: &Vec<FormatError>) -> String {
+pub fn get_errors_serialized(errors: &[FormatError]) -> String {
     errors.iter().map(|err| format!("{}", err)).collect::<Vec<_>>().join("\n")
 }
